"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Command = void 0;
const ContentstackDeliverySDK = require("contentstack");
const url = require("url");
const cli_utilities_1 = require("@contentstack/cli-utilities");
const defaultRateLimit = 5;
class ContentstackCommand extends cli_utilities_1.Command {
    get context() {
        // @ts-ignore
        return this.config.context;
    }
    get email() {
        if (this._email)
            return this._email;
        this._email = cli_utilities_1.configHandler.get('email');
        if (this._email)
            return this._email;
        throw new cli_utilities_1.CLIError('You are not logged in. Please login with command $ csdx auth:login');
    }
    get deliveryAPIClient() {
        if (this._deliveryAPIClient)
            return this._deliveryAPIClient;
        this._deliveryAPIClient = ContentstackDeliverySDK;
        return this._deliveryAPIClient;
    }
    get region() {
        if (this._region)
            return this._region;
        this._region = cli_utilities_1.configHandler.get('region');
        if (this._region)
            return this._region;
    }
    get rateLimit() {
        this._rateLimit = cli_utilities_1.configHandler.get('rate-limit');
        if (this._rateLimit)
            return this._rateLimit;
        return defaultRateLimit;
    }
    get cmaHost() {
        let cma = this.region.cma;
        if (cma.startsWith('http')) {
            const u = url.parse(cma);
            if (u.host)
                return u.host;
        }
        return cma;
    }
    get cdaHost() {
        let cda = this.region.cda;
        if (cda.startsWith('http')) {
            const u = url.parse(cda);
            if (u.host)
                return u.host;
        }
        return cda;
    }
    get cdaAPIUrl() {
        let cda = this.region.cda;
        return cda.startsWith('http') ? cda : `https://${cda}`;
    }
    get cmaAPIUrl() {
        let cma = this.region.cma;
        return cma.startsWith('http') ? cma : `https://${cma}`;
    }
    get authToken() {
        if (this._authToken)
            return this._authToken;
        this._authToken = cli_utilities_1.configHandler.get('authtoken');
        if (this._authToken)
            return this._authToken;
    }
    getToken(alias) {
        if (alias) {
            const token = cli_utilities_1.configHandler.get(`tokens.${alias}`);
            if (token)
                return token;
        }
        throw new cli_utilities_1.CLIError('No token found');
    }
    isAuthenticated() {
        const authtoken = cli_utilities_1.configHandler.get('authtoken');
        if (authtoken) {
            return true;
        }
        else {
            return false;
        }
    }
}
exports.Command = ContentstackCommand;
module.exports = {
    Command: ContentstackCommand,
};
